@@ -1,6 +1,7 @@
 import inspect
 from typing import (
     Any,
+    Callable,
     Generic,
     List,
     Optional,
@@ -11,9 +12,11 @@ from typing import (
 )
 
 from fastapi import APIRouter, Request, Response
+from fastapi.routing import APIRoute
+from pydantic import BaseModel
+
 from fastapi_resources.resources.base_resource import Resource
 from fastapi_resources.routers import decorators
-from pydantic import BaseModel
 
 
 class TCreatePayload(BaseModel):
@@ -37,6 +40,22 @@ class Action(Protocol):
         ...
 
 
+class ResourceRoute(APIRoute):
+    def get_route_handler(self) -> Callable:
+        original_route_handler = super().get_route_handler()
+
+        async def custom_route_handler(request: Request) -> Response:
+            response: Response = await original_route_handler(request)
+
+            if resource := getattr(request, "resource", None):
+                print("CLOSING")
+                resource.close()
+
+            return response
+
+        return custom_route_handler
+
+
 class ResourceRouter(APIRouter, Generic[TResource]):
     resource_class: type[TResource]
 
@@ -46,7 +65,7 @@ class ResourceRouter(APIRouter, Generic[TResource]):
         resource_class: Optional[type[TResource]] = None,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
+        super().__init__(route_class=ResourceRoute, **kwargs)
 
         if resource_class:
             self.resource_class = resource_class
@@ -183,7 +202,12 @@ class ResourceRouter(APIRouter, Generic[TResource]):
                 )(func)
 
     def get_resource(self, request: Request):
-        return self.resource_class(**self.get_resource_kwargs(request=request))
+        kwargs = self.get_resource_kwargs(request=request)
+        resource = self.resource_class(**kwargs)
+
+        setattr(request, "resource", resource)
+
+        return resource
 
     def get_resource_kwargs(self, request: Request):
         return {}
